@@ -42,12 +42,13 @@ class PyQt(PyQtProject):
         self.bindings_factories = [QtCore, QtNetwork, QtGui, QtQml, QtWidgets,
                 QtDBus, QtDesigner, QtHelp, QtOpenGL, QtOpenGLWidgets,
                 QtPrintSupport, QtQuick, QtQuick3D, QtQuickWidgets, QtSql,
-                QtSvg, QtSvgWidgets, QtTest, QtXml]
+                QtSvg, QtSvgWidgets, QtTest, QtXml, QtMultimedia,
+                QtMultimediaWidgets, QtPositioning, QtRemoteObjects, QtSensors,
+                QtSerialPort, QtWebChannel, QtWebSockets, QtBluetooth, QtNfc,
+                QAxContainer]
 
         # These are still to be ported to Qt6:
-        #   QAxContainer, QtBluetooth, QtMultimedia, QtMultimediaWidgets,
-        #   QtNfc, QtPositioning, QtLocation, QtRemoteObjects, QtSensors,
-        #   QtSerialPort, QtTextToSpeech, QtWebChannel, QtWebSockets
+        #   QtLocation, QtTextToSpeech
 
     def apply_user_defaults(self, tool):
         """ Set default values where needed. """
@@ -80,7 +81,7 @@ def find_qt():
     if not os.path.isfile(dll_dir + qtcore_dll):
         path = os.environ['PATH']
 
-        dll_dir = os.path.dirname(__file__) + '\\\\Qt\\\\bin'
+        dll_dir = os.path.dirname(__file__) + '\\\\Qt6\\\\bin'
         if os.path.isfile(dll_dir + qtcore_dll):
             path = dll_dir + ';' + path
             os.environ['PATH'] = path
@@ -180,7 +181,7 @@ del find_qt
         # Make sure the bindings are buildable.
         super().update(tool)
 
-        # PyQtWebEngine needs to know if QtWebChannel is available.
+        # PyQt6-WebEngine needs to know if QtWebChannel is available.
         if 'QtWebChannel' not in self.bindings:
             qtcore = self.bindings.get('QtCore')
             if qtcore is not None:
@@ -632,8 +633,8 @@ class QtMultimedia(PyQtBindings):
         """ Initialise the bindings. """
 
         super().__init__(project, 'QtMultimedia', qmake_QT=['multimedia'],
-                test_headers=['QAudioDeviceInfo'],
-                test_statement='new QAudioDeviceInfo()')
+                test_headers=['QAudioDevice'],
+                test_statement='new QAudioDevice()')
 
 
 class QtMultimediaWidgets(PyQtBindings):
@@ -643,7 +644,7 @@ class QtMultimediaWidgets(PyQtBindings):
         """ Initialise the bindings. """
 
         super().__init__(project, 'QtMultimediaWidgets',
-                qmake_QT=['multimediawidgets', 'multimedia'],
+                qmake_QT=['multimediawidgets'],
                 test_headers=['QVideoWidget'],
                 test_statement='new QVideoWidget()')
 
