@@ -229,6 +229,10 @@ public:
     // The Qt meta-type.
     QMetaType metatype;
 
+    // The type identifer.  This will be the meta-type identifier or -1 if the
+    // type is char *.
+    int typeId() const {return _is_char_star ? -1 : metatype.id();}
+
 private:
     // The generated type structure.  This may be 0 if the type is known by Qt
     // but hasn't been wrapped.
@@ -247,6 +251,9 @@ private:
     // The C++ name of the type.
     QByteArray _name;
 
+    // Set if the C++ type is char *.  This needs special handling.
+    bool _is_char_star;
+
     // The registered int types.
     static QSet<PyObject *> _py_enum_types;
 
