@@ -1,9 +1,8 @@
-// This defines the interfaces to the Q_ENUM, Q_ENUMS, Q_FLAG and Q_FLAGS
-// support.
+// This defines the interfaces to the pyqtEnum support.
 //
-// Copyright (c) 2022 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2021 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -24,24 +23,20 @@
 
 
 #include <QByteArray>
-#include <QHash>
 #include <QList>
+#include <QPair>
 
 
+// Encapsulate the definition of a Python enum as required by QMetaEnum.
 struct EnumFlag
 {
-    EnumFlag(const char *name_, bool isFlag_) : name(name_), isFlag(isFlag_), isScoped(false)
-    {
-    }
-
     QByteArray name;
     bool isFlag;
-    bool isScoped;
-    QHash<QByteArray, int> keys;
+    QList<QPair<QByteArray, int> > keys;
 };
 
 
-QList<EnumFlag> qpycore_get_enums_flags_list();
+EnumFlag qpycore_pop_enum_flag(PyObject *enum_cls);
 
 
 #endif
